---
layout: doc
title: Help
categories: extra
permalink: /support
---

If you can't find your answer from the documentation and examples page, you can use the support to find the appropriate solution.

#### Community support
If you are using the open-source license of Introjs, you can use [Github issues](https://github.com/usablica/intro.js/issues) or [Stackoverflow](http://stackoverflow.com/questions/tagged/intro.js) to ask your question and get an answer from the community.


#### Introjs support

First of all, please consider obtaining a license for your Introjs instance if you haven't already. Then contact us using following email and our team will help you to get your answers.

<ul>
<li>Do you need any help to setup your <b>Introjs</b>?</li> 
<li>Do you want to customize your <b>Introjs</b>?</li>
<li>Do you have any questions about the library?</li> 
</ul>

<a href="mailto:support@introjs.com">Contact us</a> and we will be more than happy to help you.

<p>
<i style="color: #E91E63" class="fa fa-heart fa-5x animated tada infinite"></i>
</p>
